/* Definitions for GNU textutils, processed by autoheader.
   Copyright (C) 1995 Free Software Foundation, Inc.
*/

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* The concatenation of the strings "GNU ", and PACKAGE.  */
#undef GNU_PACKAGE

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define to 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define to rpl_memcmp if the replacement function should be used.  */
#undef memcmp

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to 1 if ANSI function prototypes are usable.  */
#undef PROTOTYPES

/* Define to the version of the distribution.  */
#undef VERSION

/* Define to 1 if GNU regex should be used instead of GNU rx.  */
#undef WITH_REGEX

/* Define to the email address of the ftape maintainer */
#undef THE_FTAPE_MAINTAINER

/* Define if strptime is present AND works */
#undef HAVE_STRPTIME

/* Define to 1 if minor() macro (or function) is present */
#undef HAVE_MINOR

@BOTTOM@

/* Define for backwards compatibility */
#define CONFIG_ZFT_OBSOLETE

